Crate wai_bindgen_wasmtime_impl

Crate wai_bindgen_wasmtime_impl 

Macros

export
Generate code to support implementing the given interfaces and exporting them to wasm modules.
import
Generate code to support consuming the given interfaces, importaing them from wasm modules.