Skip to main contentCrate wai_bindgen_wasmtime_impl
Source - export
- Generate code to support implementing the given interfaces and exporting
them to wasm modules.
- import
- Generate code to support consuming the given interfaces, importaing them
from wasm modules.